@@ -276,12 +276,12 @@ else
 	Permission is granted to copy, distribute, and/or modify this document
 	under the terms of the GNU Free Documentation License, Version 1.2 or
 	any later version published by the Free Software Foundation; with no
-	Invariant Sections, with the Front-Cove Texts being ``A Manual,''
+	Invariant Sections, with the Front-Cover Texts being \`\`A Manual,''
 	and with the Back-Cover Texts as in (a) below. A copy of the
-	license is included in the section entitled ``GNU Free Documentation
+	license is included in the section entitled \`\`GNU Free Documentation
 	License.''
 
-	(a) The Back-Cover Text is: ``You have freedom to copy and modify
+	(a) The Back-Cover Text is: \`\`You have freedom to copy and modify
 	this Manual, like GNU software.''
 	@end quotation
 	@end copying
